@@ -2,7 +2,10 @@
 Offsets
 -------
 """
+
+from .brighteststar_guiding import BrightestStarGuiding
 from .offsets import Offsets
+from .add_pixeloffset import AddPixelOffset
 from .astrometry import AstrometryOffsets
 from .brighteststar import BrightestStarOffsets
 from .nstar.nstar import NStarOffsets
@@ -10,14 +13,18 @@ from .projected import ProjectedOffsets
 from .fitsheader import FitsHeaderOffsets
 from .dummyoffsets import DummyOffsets
 from .dummyskyoffsets import DummySkyOffsets
+from .spilled_light import SpilledLightGuiding
 
 __all__ = [
     "Offsets",
+    "AddPixelOffset",
     "AstrometryOffsets",
     "NStarOffsets",
     "ProjectedOffsets",
     "FitsHeaderOffsets",
     "BrightestStarOffsets",
+    "BrightestStarGuiding",
     "DummyOffsets",
-    "DummySkyOffsets"
+    "DummySkyOffsets",
+    "SpilledLightGuiding",
 ]
