@@ -1,6 +1,4 @@
 from abc import ABCMeta, abstractmethod
-from typing import List, Tuple
-
 from astropy.table import QTable
 
 from pyobs.images import Image
@@ -11,13 +9,10 @@ class _PhotometryCalculator(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def catalog(self) -> QTable:
-        ...
+    def catalog(self) -> QTable: ...
 
     @abstractmethod
-    def set_data(self, image: Image):
-        ...
+    def set_data(self, image: Image): ...
 
     @abstractmethod
-    def __call__(self, diameter: int):
-        ...
+    def __call__(self, diameter: int): ...
