@@ -1,6 +1,6 @@
 from abc import ABCMeta
 from collections.abc import Coroutine
-from datetime import datetime
+from datetime import datetime, timezone
 import io
 import logging
 import time
@@ -317,7 +317,7 @@ class BaseVideo(Module, ImageFitsHeaderMixin, IVideo, IImageType, metaclass=ABCM
 
         # write to jpeg
         with io.BytesIO() as output:
-            PIL.Image.fromarray(data).save(output, format="jpeg")
+            PIL.Image.fromarray(np.flip(data, axis=0)).save(output, format="jpeg")
             return output.getvalue()
 
     async def _set_image(self, data: NDArray[Any]) -> None:
@@ -366,7 +366,7 @@ class BaseVideo(Module, ImageFitsHeaderMixin, IVideo, IImageType, metaclass=ABCM
             # store everything
             logging.info("Preparing to catch next image...")
             self._next_image = NextImage(
-                date_obs=datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f"),
+                date_obs=datetime.now(timezone.utc).strftime("%Y-%m-%dT%H:%M:%S.%f"),
                 image_type=self._image_type,
                 header_futures=await self.request_fits_headers(),
                 broadcast=broadcast,
@@ -386,8 +386,7 @@ class BaseVideo(Module, ImageFitsHeaderMixin, IVideo, IImageType, metaclass=ABCM
         """
 
         # create image
-        flipped: NDArray[Any] = np.flip(data, axis=0)  # type: ignore
-        image = Image(flipped)
+        image = Image(data)
         image.header["DATE-OBS"] = next_image.date_obs
         image.header["IMAGETYP"] = next_image.image_type.value
 
