@@ -2,7 +2,6 @@ import asyncio
 import io
 import logging
 from enum import Enum
-from functools import partial
 from inspect import Parameter
 from pprint import pprint
 from typing import Any, Optional, List
@@ -529,7 +528,6 @@ class Telegram(Module):
     async def _log_sender_thread(self) -> None:
         """Thread for sending messages."""
 
-        loop = asyncio.get_running_loop()
         while True:
             # get next entry
             user_id, message = await self._message_queue.get()
